oa_gateway_agra

Function parse_checked

pub(crate) fn parse_checked(xml: &str) -> Option<Document<'_>>
Parses xml into a tree, refusing anything nested deep enough to be a stack-overflow attempt before roxmltree — which has no depth limit of its own — ever recurses into it.